@@ -56,6 +56,14 @@ class DeviceState(IntEnum):
     OTHER = 11
 
 
+@unique
+class ProductType(IntEnum):
+    """Contains product types."""
+
+    ECOMAX_P = 0
+    ECOMAX_I = 1
+
+
 @unique
 class AlertType(IntEnum):
     """Contains alert types."""
