@@ -2,13 +2,13 @@
 from __future__ import annotations
 
 import asyncio
-from typing import ClassVar, Dict, List, Optional
-from warnings import warn
+import logging
+from typing import ClassVar
 
 from pyplumio import util
-from pyplumio.const import DeviceType, FrameType
+from pyplumio.const import ATTR_LOADED, DeviceType, FrameType
 from pyplumio.exceptions import ParameterNotFoundError, UnknownDeviceError
-from pyplumio.frames import Frame, Request, get_frame_handler
+from pyplumio.frames import DataFrameDescription, Frame, Request, get_frame_handler
 from pyplumio.helpers.factory import factory
 from pyplumio.helpers.network_info import NetworkInfo
 from pyplumio.helpers.parameter import Parameter
@@ -16,6 +16,8 @@ from pyplumio.helpers.task_manager import TaskManager
 from pyplumio.helpers.typing import DeviceDataType, NumericType, SensorCallbackType
 from pyplumio.structures.network_info import ATTR_NETWORK
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def _handler_class_path(device_type_name: str) -> str:
     """Return the handler class path for a given device type name."""
@@ -25,9 +27,9 @@ def _handler_class_path(device_type_name: str) -> str:
     return f"{device_type_name.lower()}.{device_type_name}"
 
 
-# Dictionary of device handler classes indexed by device types.
+# dictionary of device handler classes indexed by device types.
 # example: "69: ecomax.EcoMAX"
-DEVICE_TYPES: Dict[int, str] = {
+DEVICE_TYPES: dict[int, str] = {
     device_type.value: _handler_class_path(device_type.name)
     for device_type in DeviceType
 }
@@ -46,7 +48,7 @@ class Device(TaskManager):
 
     queue: asyncio.Queue
     data: DeviceDataType
-    _callbacks: Dict[str, List[SensorCallbackType]]
+    _callbacks: dict[str, list[SensorCallbackType]]
 
     def __init__(self, queue: asyncio.Queue):
         """Initialize the device object."""
@@ -55,23 +57,22 @@ class Device(TaskManager):
         self.queue = queue
         self._callbacks = {}
 
-    async def get_value(self, name: str, timeout: Optional[float] = None):
+    async def wait_for(self, name: str, timeout: float | None = None) -> None:
+        """Waits for a data."""
+        if name not in self.data:
+            await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
+
+    async def get_value(self, name: str, timeout: float | None = None):
         """Return a value. When used with parameter, only it's
         value will be returned. To get the parameter object,
         get_parameter() method must be used instead."""
-        if name not in self.data:
-            await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
-
+        await self.wait_for(name, timeout)
         value = self.data[name]
         return value.value if isinstance(value, Parameter) else value
 
-    async def get_parameter(
-        self, name: str, timeout: Optional[float] = None
-    ) -> Parameter:
+    async def get_parameter(self, name: str, timeout: float | None = None) -> Parameter:
         """Return a parameter."""
-        if name not in self.data:
-            await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
-
+        await self.wait_for(name, timeout)
         parameter = self.data[name]
         if isinstance(parameter, Parameter):
             return parameter
@@ -79,36 +80,22 @@ class Device(TaskManager):
         raise ParameterNotFoundError(f"Parameter not found ({name})")
 
     async def set_value(
-        self,
-        name: str,
-        value: NumericType,
-        timeout: Optional[float] = None,
-        await_confirmation: Optional[bool] = None,
+        self, name: str, value: NumericType, timeout: float | None = None
     ) -> bool:
-        """Set a parameter value. Name should point
+        """set a parameter value. Name should point
         to a valid parameter object, otherwise raises
         ParameterNotFoundError."""
-        if name not in self.data:
-            await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
-
+        await self.wait_for(name, timeout)
         parameter = self.data[name]
         if not isinstance(parameter, Parameter):
             raise ParameterNotFoundError(f"Parameter not found ({name})")
 
-        if await_confirmation is not None:
-            warn(
-                "Flag 'await_confirmation' for 'set_value' is deprecated. "
-                + "Use 'set_value_nowait' instead.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         return await parameter.set(value)
 
     def set_value_nowait(
-        self, name: str, value: NumericType, timeout: Optional[float] = None
+        self, name: str, value: NumericType, timeout: float | None = None
     ) -> None:
-        """Set a parameter value without waiting for the result."""
+        """set a parameter value without waiting for the result."""
         self.create_task(self.set_value(name, value, timeout))
 
     def subscribe(self, name: str, callback: SensorCallbackType) -> None:
@@ -159,6 +146,7 @@ class Addressable(Device):
 
     address: ClassVar[int]
     _network: NetworkInfo
+    _frame_types: tuple[DataFrameDescription, ...] = ()
 
     def __init__(self, queue: asyncio.Queue, network: NetworkInfo):
         """Initialize the addressable object."""
@@ -177,6 +165,25 @@ class Addressable(Device):
             for name, value in frame.data.items():
                 self.set_device_data(name, value)
 
+    async def async_setup(self) -> bool:
+        """Request initial data frames."""
+        try:
+            await asyncio.gather(
+                *{
+                    self.create_task(
+                        self.make_request(description.provides, description.frame_type)
+                    )
+                    for description in self._frame_types
+                },
+                return_exceptions=False,
+            )
+            await self.async_set_device_data(ATTR_LOADED, True)
+            return True
+        except ValueError as e:
+            _LOGGER.error("Request failed: %s", e)
+            await self.async_set_device_data(ATTR_LOADED, False)
+            return False
+
     async def make_request(
         self,
         name: str,
