@@ -1,13 +1,13 @@
 """Contains type aliases."""
 from __future__ import annotations
 
-from typing import Any, Awaitable, Callable, Dict, Literal, Tuple, Union
+from typing import Any, Awaitable, Callable, Literal, Union
 
 NumericType = Union[int, float]
-ParameterDataType = Tuple[int, int, int]
+ParameterDataType = tuple[int, int, int]
 ParameterValueType = Union[NumericType, bool, Literal["off"], Literal["on"]]
-DeviceDataType = Dict[str, Any]
+DeviceDataType = dict[str, Any]
 SensorCallbackType = Callable[[Any], Awaitable[Any]]
-VersionsInfoType = Dict[int, int]
+VersionsInfoType = dict[int, int]
 BytesType = Union[bytes, bytearray]
 MessageType = bytearray
