@@ -3,19 +3,18 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import Optional, Tuple
 
 from pyplumio.frames import Frame
 from pyplumio.helpers.typing import DeviceDataType
 
 
-def ensure_device_data(data: Optional[DeviceDataType], *args) -> DeviceDataType:
+def ensure_device_data(data: DeviceDataType | None, *args) -> DeviceDataType:
     """Make new or merge multiple device data."""
     if data is None:
         data = {}
 
     for new_data in args:
-        data = dict(data, **new_data)
+        data |= new_data
 
     return data
 
@@ -39,8 +38,8 @@ class Structure(ABC, StructureDataClass):
         self,
         message: bytearray,
         offset: int = 0,
-        data: Optional[DeviceDataType] = None,
-    ) -> Tuple[DeviceDataType, int]:
+        data: DeviceDataType | None = None,
+    ) -> tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
 
 
@@ -53,6 +52,6 @@ class StructureDecoder(Structure, ABC):
 
     @abstractmethod
     def decode(
-        self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
-    ) -> Tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
+    ) -> tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
